@@ -1,7 +1,7 @@
 import sys
 import numpy as np
 import pandas as pd
-sys.path.append('src')
+sys.path.append('hyperdrive')
 from History import Historian  # noqa autopep8
 
 
